pid_is_alive

Function pid_is_alive 

pub fn pid_is_alive(pid: i32) -> bool
Return whether pid names a live, runnable process.

This intentionally treats zombies as not alive. kill(pid, 0) reports success for zombies because the PID still exists, but a zombie sandbox runtime has already exited and can only be reaped by its parent.