pub fn pid_is_zombie(pid: i32) -> Option<bool>Expand description
Return whether pid is currently a zombie process.
Returns None when the platform cannot report process state or when the
process disappears between the existence check and the state probe.