Module process_lock

Module process_lock 

Process-held cross-platform file locks.

Functions

create_new_lock_file
Creates a new lock file and fails if the path already exists.
lock_exclusive
Acquires an exclusive process-held lock, blocking until it becomes available.
open_existing_lock_file
Opens an existing lock file without creating a missing path.
open_lock_file
Opens or creates an owner-only lock file without truncating it.
try_lock_exclusive
Attempts to acquire an exclusive process-held lock without blocking.
unlock
Releases an exclusive process-held lock.