Process-held cross-platform file locks.
Functions
- create_
new_ lock_ file - Creates a new lock file and fails if the path already exists.
- lock_
exclusive - Acquires an exclusive process-held lock, blocking until it becomes available.
- open_
existing_ lock_ file - Opens an existing lock file without creating a missing path.
- open_
lock_ file - Opens or creates an owner-only lock file without truncating it.
- try_
lock_ exclusive - Attempts to acquire an exclusive process-held lock without blocking.
- unlock
- Releases an exclusive process-held lock.